@@ -569,7 +569,8 @@ class GMailURL():
 
         qsdict = urllib.parse.parse_qs(query_string)
 
-        qsdict['to'] = [address]
+        if address:
+            qsdict['to'] = [address]
 
         if 'attachment' in qsdict:
             qsdict['attach'] = qsdict['attachment']
@@ -587,6 +588,9 @@ class GMailURL():
         if 'su' in qsdict:
             outdict["subject"] = outdict["su"]
 
+        if "body" not in qsdict:
+            outdict["body"] = " "
+
         return(outdict)
 
     def simple_gmail_url(self):
